link

# XMLRésuméLibrary: User Guide

level | Element Reference | location

## Name

link — A titled hyperlink

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
href | CDATA | None
targets | CDATA | None

## Description

The `link` element defines a single hyperlink, much like HTML's `a` (anchor) element.

### Formatting

In FO/PDF and plain text output formats, the text contained in the `link` element is formatted as if the surrounding `link` tags were not present. The `href` attribute is ignored.

In the HTML output format, the `link` element is formatted as an `a` (anchor) hyperlink.

### Parents

`link` may be contained in these elements: `achievement`, `artTitle`, `bookTitle`, `employer`, `institution`, `organization`, `para`, `project`, `publisher`, `skill`

### Attributes

`href`

  The URL that the link should point to. then be referred to by this identifier.

## See Also

`uri`, `url`.

## Examples

    <employer>
      <link href="http://www.acme.bob/">Acme Corporation</link>
    </employer>

    <para>
      The <link href="http://xmlresume.sf.net/">XML R&eacute;sum&eacute;
      Project</link> supplies tools that easily convert a single XML
      r&eacute;sum&eacute; to multiple output formats.
    </employer>

level | Element Reference | location